@@ -293,9 +293,10 @@ class Data(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
-    def get(self, key, default=None):
-        d = self._internal_dict
-        return d.get(key, default)
+    get = __getitem__
+    # def get(self, key, default=None):
+    #     d = self._internal_dict
+    #     return d.get(key, default)
 
     def items(self):
         d = self._internal_dict
@@ -510,5 +511,3 @@ def is_data(d):
     :return: True IF d IS A TYPE THAT HOLDS DATA
     """
     return d.__class__ in data_types
-
-
