@@ -25,6 +25,7 @@ def get_logger():
         return _Log
     try:
         from mo_logs import Log as _Log
+
         return _Log
     except Exception as e:
         _Log = PoorLogger()
@@ -36,23 +37,27 @@ def get_module(name):
     try:
         return importlib.import_module(name)
     except Exception as e:
-        get_logger().error("`pip install " + name.split(".")[0].replace("_", "-") + "` to enable this feature", cause=e)
+        get_logger().error(
+            "`pip install "
+            + name.split(".")[0].replace("_", "-")
+            + "` to enable this feature",
+            cause=e,
+        )
 
 
 class PoorLogger(object):
     @classmethod
     def note(cls, note, **kwargs):
-        STDOUT.write(note.encode('utf8')+b"\n")
+        STDOUT.write(note.encode("utf8") + b"\n")
 
     @classmethod
     def warning(cls, note, **kwargs):
-        STDOUT.write(b"WARNING: " + note.encode('utf8') + b"\n")
+        STDOUT.write(b"WARNING: " + note.encode("utf8") + b"\n")
 
     @classmethod
     def error(cls, note, **kwargs):
-        STDERR.write(note.encode('utf8'))
+        STDERR.write(note.encode("utf8"))
         if str("cause") in kwargs:
             raise kwargs[str("cause")]
         else:
             raise Exception(note)
-
